package
Version:
v0.0.0-...-c5a4b76
Opens a new window with list of versions in this module.
Published: Mar 26, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Svc(svc string, run func())
type Msi struct {
Task int64 `json:"task"`
Svc string `json:"svc"`
Display string `json:"display"`
Commands []string `json:"commands"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.